package com.link.core.util;

import com.alibaba.fastjson.JSONObject;
import com.github.qcloudsms.SmsMultiSender;
import com.github.qcloudsms.SmsMultiSenderResult;
import com.link.base.sms.model.SendResult;
import com.link.base.sms.model.SmsAccntLine;
import com.link.base.sms.model.SmsSend;
import com.link.base.sms.model.Temparameter;
import com.link.base.sms.model.Template;
import com.link.core.util.redisclient.LinkRedisClient;
import com.qcloud.sms.SmsSingleSender;
import com.qcloud.sms.SmsSingleSenderResult;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class SendSmsUtil {
   private static final Logger logger = LogManager.getLogger(SendSmsUtil.class);
   public static final String APPKEY = PropertyUtil.getCommonProperty("tencentAppKey");
   public static final int APPID = Integer.parseInt(PropertyUtil.getCommonProperty("tencentAppId"));
   public static final String NAtIONCODE = "86";
   public static final int allPhoneNumSendTimesLimitOneDay = 100000;
   public static final int singlePhoneNumSendTimesLimitOneDay = 100;
   public static final String host = "http://sms.market.alicloudapi.com";
   public static final String path = "/singleSendSms";
   public static final String method = "GET";
   private static final String appCode = PropertyUtil.getCommonProperty("AppCode");
   public static final String signName = "Link产品";
   public static final String redisKeyForMsgTotalPrefix = "MsgCounter#";
   public static final String redisFieldTotal = "Total";

   public static void main(String[] args) {
      LinkedHashMap<String, String> param = new LinkedHashMap();
      param.put("no", "224512");
      System.out.println(sendMsg("", "SMS_50065081", param, "VertificationCode") + APPKEY + APPID);
   }

   private static String send(String phoneNumber, String templateCode, Map<String, String> param) {
      Map<String, String> headers = new HashMap();
      headers.put("Authorization", appCode);
      Map<String, String> querys = new HashMap();
      querys.put("ParamString", JSONObject.toJSONString(param));
      querys.put("RecNum", phoneNumber);
      querys.put("SignName", "Link产品");
      querys.put("TemplateCode", templateCode);

      String str;
      try {
         HttpResponse response = HttpUtils.doGet("http://sms.market.alicloudapi.com", "/singleSendSms", "GET", headers, querys);
         str = EntityUtils.toString(response.getEntity());
         logger.debug("短信[" + templateCode + "] 发送 [" + phoneNumber + "]: " + str);
         return str;
      } catch (Exception var7) {
         Exception e = var7;
         logger.error("MsgUtil捕获异常: ", e);
         str = "{\"success\":false,\"result\":\"" + e.getMessage() + "\"}";
         return str;
      }
   }

   public static String sendMsg(String phoneNumber, String templateCode, LinkedHashMap<String, String> param, String msgType) {
      String beforeSendResult = beforeSend(phoneNumber);
      if (beforeSendResult != null) {
         return beforeSendResult;
      } else if ("Ali".equals(PropertyUtil.getCommonProperty("SMS_PLATFORM"))) {
         String sendResult = send(phoneNumber, templateCode, param);
         if (sendResult != null && sendResult.contains("\"success\":true")) {
            System.out.println("true");
            afterSend(phoneNumber);
            if (!StringUtils.isBlank(msgType)) {
               upsertMsgType(phoneNumber, templateCode, param, msgType);
            }

            return sendResult;
         } else {
            return sendResult != null ? sendResult : "{\"success\":false,\"result\":null}";
         }
      } else {
         try {
            int temId = Integer.valueOf(templateCode);
            ArrayList<String> paramList = new ArrayList(param.values());
            SmsSingleSender singleSender = new SmsSingleSender(APPID, APPKEY);
            SmsSingleSenderResult singleSenderResult = singleSender.sendWithParam("86", phoneNumber, temId, paramList, "", "", "");
            if (singleSenderResult.result == 0) {
               afterSend(phoneNumber);
               if (!StringUtils.isBlank(msgType)) {
                  upsertMsgType(phoneNumber, templateCode, param, msgType);
               }

               logger.debug("短信[" + templateCode + "]发送[ " + phoneNumber + " ] 成功");
               return "{\"success\":true}";
            } else {
               logger.error(singleSenderResult);
               return "{\"success\":false,\"result\":null}";
            }
         } catch (Exception var9) {
            Exception e = var9;
            logger.error("短信发送[ " + phoneNumber + " ]错误: " + e.getMessage());
            return "{\"success\":false,\"result\":" + e.getMessage() + "}";
         }
      }
   }

   public static Map<String, Object> sendMsg2(String phoneNumber, String templateCode, LinkedHashMap<String, String> param, String msgType) {
      String resultStr = sendMsg(phoneNumber, templateCode, param, msgType);
      return (Map)JsonUtil.fromJsonStringToT(resultStr, Map.class);
   }

   private static void upsertMsgType(String phoneNumber, String templateCode, Map<String, String> param, String msgType) {
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         String redisKey = msgType + phoneNumber;
         jedis.hmset(redisKey, param);
         jedis.hset(redisKey, "Time", String.valueOf(System.currentTimeMillis()));
         jedis.hset(redisKey, "TemplateCode", templateCode);
         jedis.expire(redisKey, 86400);
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   private static String beforeSend(String phoneNumber) {
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         String allTotalStr = jedis.hget("MsgCounter#", "Total");
         String totalStr;
         String var12;
         if (allTotalStr != null) {
            int allTotal = Integer.valueOf(allTotalStr);
            if (allTotal >= 100000) {
               totalStr = "您好，很抱歉当前系统发送验证码次数已超出限制，今天暂时内无法再发送信息！";
               var12 = "{\"success\":false,\"result\":\"" + totalStr + "\"}";
               return var12;
            }
         }

         String redisKey = "MsgCounter#" + phoneNumber;
         totalStr = jedis.hget(redisKey, "Total");
         if (totalStr == null) {
            var12 = null;
            return var12;
         }

         int total = Integer.valueOf(totalStr);
         if (total >= 100) {
            String errorMsg = "该号码【" + phoneNumber + "】今天发送" + total + "次，请勿频繁发送";
            String var7 = "{\"success\":false,\"result\":\"" + errorMsg + "\"}";
            return var7;
         }
      } finally {
         RedisUtil.returnResource(jedis);
      }

      return null;
   }

   private static void afterSend(String phoneNumber) {
      LinkRedisClient jedis = null;

      try {
         jedis = RedisUtil.getJedis();
         int leftDay = (int)((getThisDayEndTime() - System.currentTimeMillis()) / 1000L);
         String allTotalStr = jedis.hget("MsgCounter#", "Total");
         if (allTotalStr == null) {
            jedis.hset("MsgCounter#", "Total", "1");
            jedis.expire("MsgCounter#", leftDay);
         } else {
            jedis.hset("MsgCounter#", "Total", String.valueOf(Integer.valueOf(allTotalStr) + 1));
            jedis.expire("MsgCounter#", leftDay);
         }

         String redisKey = "MsgCounter#" + phoneNumber;
         String totalStr = jedis.hget(redisKey, "Total");
         if (totalStr != null) {
            jedis.hset(redisKey, "Total", String.valueOf(Integer.valueOf(totalStr) + 1));
         } else {
            jedis.hset(redisKey, "Total", "1");
            jedis.expire(redisKey, leftDay);
         }
      } finally {
         RedisUtil.returnResource(jedis);
      }

   }

   public static long getThisDayStartTime() {
      Calendar calendar = Calendar.getInstance();
      calendar.setTime(new Date());
      calendar.set(11, 0);
      calendar.set(12, 0);
      calendar.set(13, 0);
      Date start = calendar.getTime();
      return start.getTime();
   }

   public static long getThisDayEndTime() {
      Calendar calendar = Calendar.getInstance();
      calendar.setTime(new Date());
      calendar.set(11, 23);
      calendar.set(12, 59);
      calendar.set(13, 59);
      Date end = calendar.getTime();
      return end.getTime();
   }

   public static List<SendResult> sendSms(SmsSend SmsSend) {
      SendResult sendResult = null;
      List<SendResult> resus = new ArrayList();
      ArrayList<String> params = new ArrayList();
      Template tem = SmsSend.getTemplate();
      Temparameter te = SmsSend.getTemparameter();
      if (!StringUtils.isNull(te.getParameter1())) {
         params.add(te.getParameter1());
         if (!StringUtils.isNull(te.getParameter2())) {
            params.add(te.getParameter2());
            if (!StringUtils.isNull(te.getParameter3())) {
               params.add(te.getParameter3());
               if (!StringUtils.isNull(te.getParameter4())) {
                  params.add(te.getParameter4());
                  if (!StringUtils.isNull(te.getParameter5())) {
                     params.add(te.getParameter5());
                     if (!StringUtils.isNull(te.getParameter6())) {
                        params.add(te.getParameter6());
                        if (!StringUtils.isNull(te.getParameter7())) {
                           params.add(te.getParameter7());
                           if (!StringUtils.isNull(te.getParameter8())) {
                              params.add(te.getParameter8());
                              if (!StringUtils.isNull(te.getParameter9())) {
                                 params.add(te.getParameter9());
                                 if (!StringUtils.isNull(te.getParameter10())) {
                                    params.add(te.getParameter10());
                                 }
                              }
                           }
                        }
                     }
                  }
               }
            }
         }
      }

      List<SmsAccntLine> account = SmsSend.getSmsAccntLineList();
      ArrayList<String> phoneNumbers = new ArrayList();
      Iterator var8 = account.iterator();

      while(var8.hasNext()) {
         SmsAccntLine arr = (SmsAccntLine)var8.next();
         phoneNumbers.add(arr.getMobilePhone1());
      }

      Iterator var10;
      if (account.size() > 1) {
         try {
            SmsMultiSender multiSender = new SmsMultiSender(APPID, APPKEY);
            SmsMultiSenderResult sendWithParam = multiSender.sendWithParam("86", phoneNumbers, tem.getTemplID(), params, SmsSend.getSigText(), SmsSend.getExtend(), SmsSend.getExt());
            var10 = sendWithParam.details.iterator();

            while(var10.hasNext()) {
               SmsMultiSenderResult.Detail deteil = (SmsMultiSenderResult.Detail)var10.next();
               Iterator var12 = account.iterator();

               while(var12.hasNext()) {
                  SmsAccntLine Account = (SmsAccntLine)var12.next();
                  if (StringUtils.equals(deteil.phoneNumber, Account.getMobilePhone1())) {
                     sendResult = new SendResult(deteil.result, deteil.errMsg, deteil.fee, deteil.phoneNumber, deteil.nationCode, deteil.sid, SmsSend.getId(), sendWithParam.ext, Account.getId(), Account, getRequestStatus(deteil.result));
                     resus.add(sendResult);
                  }
               }
            }
         } catch (Exception var15) {
            Exception e = var15;
            logger.error("SendSmsUtil捕获异常: ", e);
         }
      } else {
         try {
            com.github.qcloudsms.SmsSingleSender sender = new com.github.qcloudsms.SmsSingleSender(APPID, APPKEY);
            com.github.qcloudsms.SmsSingleSenderResult result = sender.sendWithParam("86", (String)phoneNumbers.get(0), tem.getTemplID(), params, SmsSend.getSigText(), SmsSend.getExtend(), SmsSend.getExt());
            var10 = account.iterator();

            while(var10.hasNext()) {
               SmsAccntLine C = (SmsAccntLine)var10.next();
               sendResult = new SendResult(result.result, result.errMsg, result.fee, (String)phoneNumbers.get(0), "86", result.sid, SmsSend.getId(), result.ext, C.getId(), C, getRequestStatus(result.result));
               resus.add(sendResult);
            }
         } catch (Exception var14) {
            Exception e = var14;
            logger.error("SendSmsUtil捕获异常: ", e);
         }
      }

      return resus;
   }

   public static String getRequestStatus(int idex) {
      String requestStatus;
      if (0 == idex) {
         requestStatus = "SUCCESS";
      } else {
         requestStatus = "FAIL";
      }

      return requestStatus;
   }
}
